@@ -120,7 +120,6 @@ def read_custom_tags(
     album_fields["label"] = audio_file.label
     album_fields["media"] = audio_file.media
     album_fields["original_date"] = audio_file.original_date
-    album_fields["path"] = track_path.parent
     album_fields["title"] = audio_file.album
     album_fields["track_total"] = audio_file.tracktotal
 
@@ -130,7 +129,6 @@ def read_custom_tags(
     track_fields["disc"] = audio_file.disc
     if audio_file.genres is not None:
         track_fields["genres"] = set(audio_file.genres)
-    track_fields["path"] = track_path
     track_fields["title"] = audio_file.title
     track_fields["track_num"] = audio_file.track
 
@@ -155,7 +153,6 @@ class MetaTrack(MetaLibItem):
         artist (Optional[str])
         artists (Optional[set[str]]): Set of all artists.
         disc (Optional[int]): Disc number the track is on.
-        genre (Optional[str]): String of all genres concatenated with ';'.
         genres (Optional[set[str]]): Set of all genres.
         title (Optional[str])
         track_num (Optional[int])
@@ -180,15 +177,12 @@ class MetaTrack(MetaLibItem):
         album.tracks.append(self)
 
         self.track_num = track_num
-        self.artist = artist
+        self.artist = artist or self.album_obj.artist
         self.artists = artists
         self.disc = disc
         self.genres = genres
         self.title = title
 
-        # set default values
-        self.artist = self.album_obj.artist
-
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -316,11 +310,7 @@ class Track(LibItem, SABase, MetaTrack):
         album_obj (Album): Corresponding Album object.
         artist (str)
         artists (Optional[set[str]]): Set of all artists.
-        audio_format (str): File audio format.
-            One of ['aac', 'aiff', 'alac', 'ape', 'asf', 'dsf', 'flac', 'ogg', 'opus',
-            'mp3', 'mpc', 'wav', 'wv']
         disc (int): Disc number the track is on.
-        genre (str): String of all genres concatenated with ';'.
         genres (Optional[set[str]]): Set of all genres.
         path (Path): Filesystem path of the track file.
         title (str)
@@ -384,12 +374,12 @@ class Track(LibItem, SABase, MetaTrack):
         self.title = title
         self.track_num = track_num
 
-        # set default values
-        self.artist = self.albumartist
-
         for key, value in kwargs.items():
             setattr(self, key, value)
 
+        if self.artist is None:
+            self.artist = self.albumartist
+
         if not self.disc:
             self.disc = self._guess_disc()
 
@@ -439,6 +429,7 @@ class Track(LibItem, SABase, MetaTrack):
 
         Raises:
             TrackError: Given ``path`` does not correspond to a track file.
+            ValueError: Track is missing required fields.
         """
         log.debug(f"Creating track from path. [path={track_path}, {album=}]")
 
@@ -455,21 +446,46 @@ class Track(LibItem, SABase, MetaTrack):
         config.CONFIG.pm.hook.read_custom_tags(
             track_path=track_path, album_fields=album_fields, track_fields=track_fields
         )
+
+        title = track_fields.pop("title")
+        track_num = track_fields.pop("track_num")
+
+        album_artist = album_fields.pop("artist")
+        album_title = album_fields.pop("title")
+        date = album_fields.pop("date")
+        disc_total = album_fields.pop("disc_total") or 1
+
+        missing_reqd_fields = []
+        if not title:
+            missing_reqd_fields.append("title")
+        if not track_num:
+            missing_reqd_fields.append("track_num")
+        if not album_artist and not album:
+            missing_reqd_fields.append("album_artist")
+        if not album_title and not album:
+            missing_reqd_fields.append("album_title")
+        if not date and not album:
+            missing_reqd_fields.append("date")
+        if missing_reqd_fields:
+            raise ValueError(
+                f"Track is missing required fields. [{missing_reqd_fields=!r}]"
+            )
+
         if not album:
             album = Album(
-                path=album_fields.pop("path"),
-                artist=album_fields.pop("artist"),
-                title=album_fields.pop("title"),
-                date=album_fields.pop("date"),
-                disc_total=album_fields.pop("disc_total"),
+                path=track_path.parent,
+                artist=album_artist,
+                title=album_title,
+                date=date,
+                disc_total=disc_total,
                 **album_fields,
             )
 
         return cls(
             album=album,
-            path=track_fields.pop("path"),
-            title=track_fields.pop("title"),
-            track_num=track_fields.pop("track_num"),
+            path=track_path,
+            title=title,
+            track_num=track_num,
             **track_fields,
         )
 
@@ -482,11 +498,28 @@ class Track(LibItem, SABase, MetaTrack):
         """
         return mediafile.MediaFile(self.path).type
 
+    @property
+    def bit_depth(self) -> int:
+        """Returns the number of bits per sample in the audio encoding.
+
+        The bit depth is an integer and zero when unavailable or when the file format
+        does not support bit depth.
+        """
+        return mediafile.MediaFile(self.path).bitdepth
+
     @property
     def fields(self) -> set[str]:
         """Returns any editable, track-specific fields."""
         return super().fields.union({"path"})
 
+    @property
+    def sample_rate(self) -> int:
+        """Returns the sampling rate of the track.
+
+        The sampling rate is in Hertz (Hz) as an integer and zero when unavailable.
+        """
+        return mediafile.MediaFile(self.path).samplerate
+
     def is_unique(self, other: "Track") -> bool:
         """Returns whether a track is unique in the library from ``other``."""
         if self.path == other.path:
